pub struct ProtocolAnalyzer { /* private fields */ }Implementations
Sourceimpl ProtocolAnalyzer
impl ProtocolAnalyzer
pub fn new() -> Self
Sourcepub fn with_timeout(probe_timeout: Duration) -> Self
pub fn with_timeout(probe_timeout: Duration) -> Self
Create a new analyzer with a custom probe timeout
Sourcepub async fn detect_service(
&self,
stream: &mut TcpStream,
protocol: Protocol,
) -> Result<Option<String>, NtraceError>
pub async fn detect_service( &self, stream: &mut TcpStream, protocol: Protocol, ) -> Result<Option<String>, NtraceError>
Detects the service running on the port via banner grabbing and probing.
Sourcepub async fn analyze_protocol(
&self,
stream: &TcpStream,
protocol: Protocol,
) -> Result<Option<String>, NtraceError>
pub async fn analyze_protocol( &self, stream: &TcpStream, protocol: Protocol, ) -> Result<Option<String>, NtraceError>
Analyzes protocol details to determine version and features